<?php
use DTElementor\Widgets\DTElementorWidgetBase;
use Elementor\Controls_Manager;
use Elementor\Utils;

class Elementor_Counter extends DTElementorWidgetBase {

    public function get_name() {
        return 'dt-counter';
    }

    public function get_title() {
        return __('Number Counter', 'dt-elementor');
    }

    public function get_icon() {
		return 'fas fa-sort-numeric-up-alt';
	}

	public function get_style_depends() {
		return array( 'counter' );
	}

	public function get_script_depends() {
		return array( 'jquery.animatenumber', 'dt.anycarousel' );
	}

    protected function register_controls() {

        $this->start_controls_section( 'dt_section_general', array(
            'label' => __( 'General', 'dt-elementor'),
        ) );

		$this->add_control( 'type', array(
			'label' => __( 'Type', 'dt-elementor' ),
			'type' => Controls_Manager::SELECT,
			'default' => 'type1',
			'options' => array(
				'type1' => __( 'Type 1', 'dt-elementor' ),
				'type2' => __( 'Type 2', 'dt-elementor' ),
				'type3' => __( 'Type 3', 'dt-elementor' ),
				'type4' => __( 'Type 4', 'dt-elementor' ),
				'type5' => __( 'Type 5', 'dt-elementor' ),
				'type6' => __( 'Type 6', 'dt-elementor' ),
				'type7' => __( 'Type 7', 'dt-elementor' ),
			),
			'frontend_available' => true
		));

		$this->add_control( 'icon', array(
			'type'    => Controls_Manager::MEDIA,
			'label'   => __('Icon', 'dt-elementor'),
			'default' => array( 'url' => \Elementor\Utils::get_placeholder_image_src(), ),
		) );

		$this->add_control( 'icon_color', array(
			'label' => __( 'Icon Color', 'dt-elementor' ),
			'type' => Controls_Manager::SELECT,
			'default' => 'type1',
			'options' => array(
				'' => __( 'None', 'dt-elementor' ),
				'blue'		 => __( 'Blue', 'dt-elementor' ),
				'brown' 	 => __( 'Brown', 'dt-elementor' ),
				'cadetblue'  => __( 'CadetBlue', 'dt-elementor' ),
				'chillipepper' => __( 'Chillipepper', 'dt-elementor' ),
				'cyan' 		 => __( 'Cyan', 'dt-elementor' ),
				'darkgolden' => __( 'DarkGolden', 'dt-elementor' ),
				'deeporange' => __( 'DeepOrange', 'dt-elementor' ),
				'deeppurple' => __( 'DeepPurple', 'dt-elementor' ),
				'green' 	 => __( 'Green', 'dt-elementor' ),
				'lime' 		 => __( 'lime', 'dt-elementor' ),
				'magenta' 	 => __( 'Magenta', 'dt-elementor' ),
				'orange' 	 => __( 'Orange', 'dt-elementor' ),
				'pink' 	 	 => __( 'Pink', 'dt-elementor' ),
				'purple' 	 => __( 'Purple', 'dt-elementor' ),
				'red' 		 => __( 'Red', 'dt-elementor' ),
				'skyblue' 	 => __( 'Skyblue', 'dt-elementor' ),
				'teal' 		 => __( 'Teal', 'dt-elementor' ),
				'turquoise'  => __( 'Turquoise', 'dt-elementor' ),
				'wisteria' 	 => __( 'Wisteria', 'dt-elementor' ),
				'yellow' 	 => __( 'Yellow', 'dt-elementor' ),
			),
			'frontend_available' => true
		));

		$this->add_control( 'value', array(
			'label' => __( 'Number Value', 'dt-elementor' ),
			'type' => Controls_Manager::NUMBER,
			'default' => 1000,
			'frontend_available' => true
		));

		$this->add_control( 'append', array(
			'type'        => Controls_Manager::TEXT,
			'label'       => __('Append Text', 'dt-elementor'),
			'frontend_available' => true
		) );

		$this->add_control( 'title', array(
			'type'        => Controls_Manager::TEXT,
			'label'       => __('Title', 'dt-elementor'),
			'frontend_available' => true
		) );

		$this->add_control( 'subtitle', array(
			'type'        => Controls_Manager::TEXT,
			'label'       => __('Sub Title', 'dt-elementor'),
			'frontend_available' => true,
			'condition' => array(
				'type' => 'type7'
			),
		) );

		$this->add_control( 'el_class', array(
			'type'        => Controls_Manager::TEXT,
			'label'       => __('Extra class name', 'dt-elementor'),
			'description' => __('Style particular element differently - add a class name and refer to it in custom CSS', 'dt-elementor')
		) );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        extract($settings);

		$append = !empty($append) ? "data-append='{$append}'" : '';

		$out = "<div class='dt-sc-counter {$type} {$icon_color} {$el_class}'>";
			$out .= "<div class='dt-sc-counter-icon-holder'>";
				$out .= "<div class='icon-wrapper'>";
						if( isset( $icon ) ):
							$image = wp_get_attachment_image( $icon['id'], 'full' );
							$image = $image;
						else:
							$image = '<img src="'.$icon['url'].'" alt="'.$name.'" />';
						endif;

						$out .= '<span>'.$image.'</span>';
				$out .= "</div>";

				if( !empty($title) && $type == 'type7' )
					$out .= "<h4>{$title}</h4>";

				$out .= "<div class='dt-sc-counter-number' data-value='{$value}' {$append}>{$value}</div>";

				if( !empty($subtitle) && $type == 'type7' )
					$out .= '<span class="dt-sc-counter-subtitle">'.$subtitle.'</span>';
			$out .= "</div>";

			if( !empty($title) && $type != 'type7' )
				$out .= "<h4>{$title}</h4>";

		$out .= "</div>";

		echo $out;
	}

    protected function _content_template() {
    }
}