<?php
use DTElementor\Widgets\DTElementorWidgetBase;
use Elementor\Controls_Manager;
use Elementor\Utils;

class Elementor_Testimonials extends DTElementorWidgetBase {

    public function get_name() {
        return 'dt-testimonial';
    }

    public function get_title() {
        return __('Testimonial', 'dt-elementor');
    }

    public function get_icon() {
		return 'fas fa-quote-right';
	}

	public function get_style_depends() {
		return array( 'testimonials' );
	}

	public function get_script_depends() {
		return array( 'dt.anycarousel' );
	}

    protected function register_controls() {

        $this->start_controls_section( 'dt_section_general', array(
            'label' => __( 'General', 'dt-elementor'),
        ) );

		$this->add_control( 'type', array(
			'label' => __( 'Type', 'dt-elementor' ),
			'type' => Controls_Manager::SELECT,
			'default' => 'type4',
			'options' => array(
				'type1' => __( 'Type 1', 'dt-elementor' ),
				'type2' => __( 'Type 2', 'dt-elementor' ),
				'type3' => __( 'Type 3', 'dt-elementor' ),
				'type4' => __( 'Type 4', 'dt-elementor' ),
				'type5' => __( 'Type 5', 'dt-elementor' ),
				'type6' => __( 'Type 6', 'dt-elementor' ),
				'type7' => __( 'Type 7', 'dt-elementor' ),
				'type8' => __( 'Type 8', 'dt-elementor' ),
			),
			'frontend_available' => true
		));

		$this->add_control( 'image', array(
			'type'    => Controls_Manager::MEDIA,
			'label'   => __('Image', 'dt-elementor'),
			'default' => array( 'url' => \Elementor\Utils::get_placeholder_image_src(), ),
		) );

		$this->add_control( 'name', array(
			'type'        => Controls_Manager::TEXT,
			'label'       => __('Name', 'dt-elementor'),
			'frontend_available' => true
		) );

		$this->add_control( 'role', array(
			'type'        => Controls_Manager::TEXT,
			'label'       => __('Role', 'dt-elementor'),
			'frontend_available' => true
		) );

		$this->add_control( 'content', array(
			'type'    => Controls_Manager::WYSIWYG,
			'label'   => __('Content', 'dt-elementor'),
			'default' => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi hendrerit elit turpis, a porttitor tellus sollicitudin at.Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos.', 'dt-elementor' ),
		) );

		$this->add_control( 'el_class', array(
			'type'        => Controls_Manager::TEXT,
			'label'       => __('Extra class name', 'dt-elementor'),
			'description' => __('Style particular element differently - add a class name and refer to it in custom CSS', 'dt-elementor')
		) );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        extract($settings);

		$image = wp_get_attachment_image( $image['id'], 'full' );
		$image = $image;
		$image = !empty( $image ) ? $image : '';

		$out = "<div class='dt-sc-testimonial-wrapper'>";
			$out .= "<div class='dt-sc-testimonial {$type} {$el_class}'>";
				$img = ""; $con = "";

				$img = '<div class="dt-sc-testimonial-author">';
					if(!empty($image))
						$img .= "<span>".$image."</span>";
					if((!empty($name) || !empty($role)) && $type != 'type1' && $type != 'type4' && $type != 'type7' ):
						$img .= '<cite>';
							if(!empty($name))
								$img .= $name;
							if(!empty($role))
								$img .= "<small>{$role}</small>";
						$img .= '</cite>';
					endif;
				$img .= '</div>';
	
				$con = '<div class="dt-sc-testimonial-quote">';
					$con .= '<blockquote>';
						$con .= '<q>'.do_shortcode( strip_tags($content) ).'</q>';
						if((!empty($name) || !empty($role)) && ($type == 'type1' || $type == 'type4' || $type == 'type7') ):
							$con .= '<cite>';
								if(!empty($name))
									$con .= $name;
								if(!empty($role))
									$con .= "<small>{$role}</small>";
							$con .= '</cite>';
						endif;
					$con .= '</blockquote>';
				$con .= '</div>';

				if($type == 'type1' || $type == 'type3' || $type == 'type4' || $type == 'type6' || $type == 'type7' || $type == 'type8')
					$out .= $img.$con;
				else
					$out .= $con.$img;

			$out .= '</div>';
        $out .= '</div>';		
		
		echo $out;
	}
}